@@ -158,4 +158,62 @@ as.table.confusionMatrix <- function(x, ...)  x$table
 
 
 
+confusionMatrix.train <- function(data, norm = "overall", dnn = c("Prediction", "Reference"), ...)
+  {
+    if(data$modelType == "Regression") stop("confusion matrices are only valid for classification models")
+    if(!norm %in% c("none", "overall", "average")) stop("values for norm should be 'none', 'overall', 'byClass' or 'average'")
+    if(data$control$method %in% c("oob", "LOOCV")) stop("cannot compute confusion matrices for leave-one-out and out-of-bag resampling")
+   if(!is.null(data$control$index))
+      {
+        resampleN <- unlist(lapply(data$control$index, length))
+        numResamp <- length(resampleN)
+        
+        resampName <- switch(tolower(data$control$method),
+                             boot =, boot632 = paste("Bootstrapped (", numResamp, " reps)", sep = ""),
+                             cv = paste("Cross-Validated (", data$control$number, " fold)", sep = ""),
+                             repeatedcv = paste("Cross-Validated (", data$control$number, " fold, repeated ",
+                               data$control$repeats, " times)", sep = ""),
+                             lgocv = paste("Repeated Train/Test Splits Estimated (", numResamp, " reps, ",
+                               round(data$control$p, 2), "%)", sep = ""))
+      } else resampName <- ""
+        
+    lev <- caret:::getClassLevels(data)
+    ## get only best tune
+    resampledCM <- merge(data$bestTune, data$resampledCM)
+    counts <- as.matrix(resampledCM[,grep("^\\.cell", colnames(resampledCM))])
+    ## normalize by true class?
+
+    if(norm == "overall") counts <- t(apply(counts, 1, function(x)x/sum(x)))
+    if(norm == "average") counts <- counts/numResamp
+    overall <- matrix(apply(counts, 2, mean), nrow = length(lev))
+    rownames(overall) <- colnames(overall) <- lev
+    overall <- overall*100
+    names(dimnames(overall)) <- dnn
+
+ 
+    out <- list(table = overall,
+                norm = norm,
+                text = paste(resampName, "Confusion Matrix"))
+    class(out) <- "confusionMatrix.train"
+    out
+  }
+
+
+print.confusionMatrix.train <- function(x, digits = 1, ...)
+{
+  cat(x$text, "\n")
+  normText <- switch(x$norm,
+                     none = "\n(entries are un-normalized counts)\n",
+                     average = "\n(entries are cell counts per resample)\n",
+                     overall = "\n(entries are percentages of table totals)\n",
+                     byClass = "\n(entries are percentages within the reference class)\n",
+                     "")
+  cat(normText, "\n")
+  print(round(x$table, digits))
+  cat("\n")
+  invisible(x)
+}
+  
+
+
 
