@@ -216,6 +216,10 @@
                       nnet =, pcaNNet = expand.grid(
                                 .size = ((1:len) * 2) - 1, 
                                 .decay = c(0, 10 ^ seq(-1, -4, length = len - 1))),
+                      avNNet =expand.grid(
+                                .size = ((1:len) * 2) - 1, 
+                                .decay = c(0, 10 ^ seq(-1, -4, length = len - 1)),
+                                .bag = FALSE),
                       hda = expand.grid(
                         .gamma = seq(0, 1, length = len), 
                         .lambda =  seq(0, 1, length = len),
