@@ -2,6 +2,7 @@ preProcess <- function(x, ...) UseMethod("preProcess")
 
 preProcess.default <- function(x, method = c("center", "scale"),
                                thresh = 0.95,
+                               pcaComp = NULL,
                                na.remove = TRUE,
                                k = 5,
                                knnSummary = mean,
@@ -113,10 +114,13 @@ preProcess.default <- function(x, method = c("center", "scale"),
   
   if(any(method == "pca"))
     {
-       if(verbose) cat("Computing PCA loadings\n")
+      if(verbose) cat("Computing PCA loadings\n")
       tmp <- prcomp(x, scale = TRUE, retx = FALSE)
-      cumVar <- cumsum(tmp$sdev^2/sum(tmp$sdev^2)) 
-      numComp <- max(2, which.max(cumVar > thresh))
+      if(is.null(pcaComp))
+        {
+          cumVar <- cumsum(tmp$sdev^2/sum(tmp$sdev^2)) 
+          numComp <- max(2, which.max(cumVar > thresh))
+        } else numComp <- pcaComp
       rot <- tmp$rotation[,1:numComp]
     } else {
       rot <- NULL
@@ -150,6 +154,7 @@ preProcess.default <- function(x, method = c("center", "scale"),
               rotation = rot,
               method = method,
               thresh = thresh,
+              pcaComp = pcaComp,
               numComp = numComp,
               ica = ica,
               k = k,
@@ -324,8 +329,14 @@ print.preProcess <- function(x, ...)
   
   if(any(x$method == "pca"))
     {
-      cat("PCA needed", x$numComp, "components to capture", round(x$thresh*100, 2),
-          "percent of the variance\n")
+      if(is.null(x$pcaComp))
+        {
+          cat("PCA needed", x$numComp, ifelse(x$numComp > 1, "components", "component"),
+              "to capture", round(x$thresh*100, 2),
+              "percent of the variance\n")
+        } else {
+          cat("PCA used", x$pcaComp, ifelse(x$pcaComp > 1, "components", "component"), "as specified.\n")
+        }
     }
   if(any(x$method == "ica"))
     {
