@@ -8,9 +8,7 @@ trainControl <- function(method = "boot",
                          classProbs = FALSE,
                          summaryFunction = defaultSummary,
                          selectionFunction = "best",
-                         PCAthresh = 0.95,
-                         ICAcomp = 3,
-                         k = 5,
+                         preProcOptions = list(thresh = 0.95, ICAcomp = 3, k = 5),
                          index = NULL,
                          timingSamps = 0,
                          workers = 1,
@@ -21,6 +19,9 @@ trainControl <- function(method = "boot",
   if(is.null(selectionFunction)) stop("null selectionFunction values not allowed")
   if(!(returnResamp %in% c("all", "final", "none"))) stop("incorrect value of returnResamp")
   if(length(predictionBounds) > 0 && length(predictionBounds) != 2) stop("'predictionBounds' should be a logical or numeric vector of length 2")
+  if(any(names(preProcOptions) == "method")) stop("'method' cannot be specified here")
+  if(any(names(preProcOptions) == "x")) stop("'x' cannot be specified here")
+  
   list(method = method,
        number = number,
        repeats = repeats,
@@ -31,9 +32,7 @@ trainControl <- function(method = "boot",
        classProbs = classProbs,
        summaryFunction = summaryFunction,
        selectionFunction = selectionFunction,
-       PCAthresh = PCAthresh,
-       ICAcomp = ICAcomp,
-       k = k,
+       preProcOptions = preProcOptions,
        index = index,
        timingSamps = timingSamps,
        workers = workers,
